package org.rcisoft.app.appArticle.controller;


/*固定导入*/

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import org.rcisoft.business.opmArticle.entity.ArticleCommentDTO;
import org.rcisoft.business.opmArticle.entity.OpmArticle;
import org.rcisoft.business.opmArticle.service.OpmArticleService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
* Created by cy on 2024年3月30日 下午1:51:15.
*/
@RestController
@RequestMapping("/app")
public class AppOpmArticleController extends CyPaginationController<OpmArticle> {


    @Autowired
    private OpmArticleService opmArticleServiceImpl;

    /**
     * 动态-发表动态
     */
    @PreAuthorize("@cyPerm.hasPerm('cms:article:add')")
    @CyOpeLogAnno(title = "system-opmArticle管理管理-新增opmArticle管理", businessType = CyLogTypeEnum.INSERT)
    @Operation(summary="添加opmArticle管理", description="添加opmArticle管理")
    @PostMapping(value = "/opmArticle/add")
    public CyResult add(@Valid @RequestBody OpmArticle opmArticle, BindingResult bindingResult) {
        CyPersistModel data = opmArticleServiceImpl.persist(opmArticle);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                opmArticle);
    }


    /**
     * 动态-动态列表
     */
    @PreAuthorize("@cyPerm.hasPerm('app:article:list')")
    @CyOpeLogAnno(title = "system-动态管理-查询动态列表", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="分页查询动态列表集合", description="分页查询动态列表集合")
    @GetMapping(value = "/open/opmArticle/queryArticleByPagination")
    public CyGridModel listByPagination(OpmArticle opmArticle) {
        opmArticleServiceImpl.findAllByPagination(getPaginationUtility(), opmArticle);
        return getGridModelResponse();
    }

    /**
     * 动态-点赞
     */
    @PreAuthorize("@cyPerm.hasPerm('app:article:like')")
    @CyOpeLogAnno(title = "system-动态管理-动态点赞", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="动态点赞", description="动态点赞")
    @PostMapping("/opmArticle/like")
    public CyResult likeAdd(Integer articleId, String praiseType) {
        CyPersistModel data = opmArticleServiceImpl.likeAdd(articleId,praiseType);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                articleId);
    }

    @PreAuthorize("@cyPerm.hasPerm('app:article:detail')")
    @CyOpeLogAnno(title = "system-opmArticle管理管理-查询opmArticle管理", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="查询单一opmArticle管理", description="查询单一opmArticle管理")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true)})
    @GetMapping("/open/opmArticle/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable Integer businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                opmArticleServiceImpl.findById(businessId));
    }

    /**
     * 动态-动态评论
     */
    @PreAuthorize("@cyPerm.hasPerm('app:article:add')")
    @CyOpeLogAnno(title = "system-opmArticle管理管理-新增评论", businessType = CyLogTypeEnum.INSERT)
    @Operation(summary="添加动态评论", description="添加动态评论")
    @PostMapping(value = "/opmArticle/comment")
    public CyResult comment(@Valid @RequestBody ArticleCommentDTO dto, BindingResult bindingResult) {
        CyPersistModel data = opmArticleServiceImpl.addComment(dto);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                dto);
    }
}
